%{
  /* definitions of manifest constants
     LT, LE, EQ, NE, GT, GE, IF, THEN, ELSE,
     ID, NUMBER, RELOP */
  enum yyconstants { LT=1,LE,EQ,NE,GT,GE,IF,THEN,ELSE,ID,NUMBER,RELOP } ;

  char *yylval;  /* semantic value of token */

%}

/* regular definitions */
delim     [ \t\n]
ws        [delim]+
letter    [A-Za-z]
digit     [0-9]
id        {letter}({letter}|{digit})*
number    {digit}+(\.{digit}+)?(E[+\-]?{digit}+)?

%%

{ws}      { /* no action and no return */ }
if        {yylval = "IF"; return(IF);}
then      {yylval = "THEN"; return(THEN);}
else      {yylval = "ELSE"; return(ELSE);}
{id}      {yylval = yytext; return(ID);}
{number}  {yylval = yytext; return(NUMBER);}
"<"       {yylval = "LT"; return(RELOP);}
"<="      {yylval = "LE"; return(RELOP);}
"="       {yylval = "EQ"; return(RELOP);}
"<>"      {yylval = "NE"; return(RELOP);}
">"       {yylval = "GT"; return(RELOP);}
">="      {yylval = "GE"; return(RELOP);}

%%

main(){
  int t;
  while (t=yylex()){
    if(t==ID)
      printf("ID(%s) ",yylval);
    else if(t==NUMBER)
      printf("NUMBER(%s) ",yylval);
    else
      printf("%s ",yylval);
    }
  printf("\n");
}
